import { EventEmitter } from "events";
import { Candle } from "../types/types_ohlc";
import { FunctionRegistry } from "./feature_dsl_parser";
export interface StrategySchema {
    name: string;
    transaction_charges?: number;
    risk_per_trade?: number;
    capital: number;
    cooldown_period?: number;
    allow_reentry?: boolean;
    warmup_period?: number;
    entry_long?: string;
    entry_short?: string;
    exit_long?: string;
    exit_short?: string;
    stop_loss_expr_long?: string;
    stop_loss_expr_short?: string;
    target_expr_long?: string;
    target_expr_short?: string;
    breakeven_trigger_expr_long?: string;
    breakeven_trigger_expr_short?: string;
    trailing_trigger_expr_long?: string;
    trailing_trigger_expr_short?: string;
    trailing_offset_expr_long?: string;
    trailing_offset_expr_short?: string;
}
export interface StrategyTrade {
    entry_index: number;
    exit_index: number;
    entry_time: string;
    exit_time: string;
    entry_price: number;
    exit_price: number;
    position_size: number;
    side: "long" | "short";
    pnl: number;
    pnl_percent: number;
    reason: "tp" | "sl" | "sl_breakeven" | "exit_condition";
    stop_price?: number;
    take_profit_price?: number;
    trailing_triggered?: boolean;
    breakeven_triggered?: boolean;
}
export interface StrategyState {
    in_position: boolean;
    entry_index: number | null;
    entry_time: string | null;
    entry_price: number | null;
    position_size: number;
    stop_price: number | null;
    take_profit_price: number | null;
    breakeven_triggered: boolean;
    trailing_stop_active: boolean;
    cooldown_remaining: number;
    side: "long" | "short" | null;
    last_exit_price?: number;
    last_exit_index?: number;
    last_exit_reason?: "tp" | "exit_condition" | "sl" | "sl_breakeven";
}
export interface StrategyReport {
    metric: {
        strategy: string;
        capital_start: number;
        capital_end: number;
        total_trades: number;
        win_rate: number;
        avg_pnl: number;
        avg_pnl_percent: number;
        avg_win: number;
        avg_loss: number;
        avg_hold: number;
        total_profit: number;
        total_time_taken: number;
    };
    trades: StrategyTrade[];
    candle_decisions: StrategyCandleDecision[];
}
export interface StrategyCandleDecision {
    index: number;
    decision: string;
    last_traded_price: number;
    stop_loss: null | number;
    take_profit: null | number;
    long_expression?: null | string;
    short_expression?: null | string;
    breakeven_expression?: null | string;
    update_sl_expression?: null | string;
    take_profit_expression?: null | string;
}
export declare class StrategyRunner extends EventEmitter {
    private start_time;
    private candles;
    private strategy;
    private function_registry;
    private trades;
    private capital;
    private state;
    private candle_decisions;
    private warmup_period;
    constructor(candles: Candle[], strategy: StrategySchema, function_registry: FunctionRegistry);
    /**
     * Validates the strategy configuration to ensure it meets minimum requirements
     * and has consistent settings.
     * @throws Error if the strategy configuration is invalid
     */
    private evaluateStrategy;
    run(): Promise<StrategyTrade[]>;
    private try_entry;
    private try_exit;
    get_report(): StrategyReport;
}
